aboutsummaryrefslogtreecommitdiffstats
path: root/win32/resource.rb
diff options
context:
space:
mode:
authornobu <nobu@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2005-03-03 09:38:40 +0000
committernobu <nobu@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2005-03-03 09:38:40 +0000
commita48c63f36b48bdad1cfea978b58410fc70fada7a (patch)
tree4f20ff4a932659300910e0c699d6735a13d8a07b /win32/resource.rb
parent813a901a5e01675e548a2fd3ede472f9a2572bc3 (diff)
downloadruby-a48c63f36b48bdad1cfea978b58410fc70fada7a.tar.gz
* {bcc32,win32,wince}/Makefile.sub (config.h): check if affected
when makefiles are modified. * {bcc32,win32,wince}/Makefile.sub (config.status): add variables for tests. * win32/ifchange.bat: try to update a file only if modified. * win32/resource.rb: more descriptions. git-svn-id: svn+ssh://ci.ruby-lang.org/ruby/trunk@8057 b2dd03c8-39d4-4d8f-98ff-823fe69b080e
Diffstat (limited to 'win32/resource.rb')
-rw-r--r--win32/resource.rb12
1 files changed, 6 insertions, 6 deletions
diff --git a/win32/resource.rb b/win32/resource.rb
index 0bfebf2d63..b5a3a8b33a 100644
--- a/win32/resource.rb
+++ b/win32/resource.rb
@@ -46,11 +46,11 @@ icons.keys.sort.each do |i|
dll_icons << "#{dll_icons.size + 1} ICON DISCARDABLE "+icons[i].dump+"\n"
end
-[ # base name extension file type icons
- [$ruby_name, CONFIG["EXEEXT"], 'VFT_APP', ruby_icon],
- [$rubyw_name, CONFIG["EXEEXT"], 'VFT_APP', rubyw_icon || ruby_icon],
- [$so_name, '.dll', 'VFT_DLL', dll_icons],
-].each do |base, ext, type, icons|
+[ # base name extension file type desc, icons
+ [$ruby_name, CONFIG["EXEEXT"], 'VFT_APP', 'CUI', ruby_icon],
+ [$rubyw_name, CONFIG["EXEEXT"], 'VFT_APP', 'GUI', rubyw_icon || ruby_icon],
+ [$so_name, '.dll', 'VFT_DLL', 'DLL', dll_icons],
+].each do |base, ext, type, desc, icons|
open(base + '.rc', "w") { |f|
f.binmode if /mingw/ =~ RUBY_PLATFORM
@@ -74,7 +74,7 @@ BEGIN
BEGIN
BLOCK "000004b0"
BEGIN
- VALUE "FileDescription", "Ruby interpreter\\0"
+ VALUE "FileDescription", "Ruby interpreter (#{desc}) #{RUBY_VERSION} [#{RUBY_PLATFORM}]\\0"
VALUE "FileVersion", "#{fversion}\\0"
VALUE "Home Page", "http://www.ruby-lang.org/\\0"
VALUE "InternalName", "#{base + ext}\\0"